@@ -4,18 +4,18 @@ URLs for the completion API
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from . import views
 
 app_name = 'completion_aggregator'
 
 urlpatterns = [
-    url(
+    re_path(
         r'^course/(?P<course_key>.+)/blocks/(?P<block_key>.+)/$',
         views.CompletionBlockUpdateView.as_view(),
         name='blockcompletion-update'
     ),
-    url(r'^course/$', views.CompletionListView.as_view(), name='aggregator-list'),
-    url(r'^course/(?P<course_key>.+)/$', views.CompletionDetailView.as_view(), name='aggregator-detail'),
+    re_path(r'^course/$', views.CompletionListView.as_view(), name='aggregator-list'),
+    re_path(r'^course/(?P<course_key>.+)/$', views.CompletionDetailView.as_view(), name='aggregator-detail'),
 ]
